### Contributing

First off, thank you for considering contributing to Mailgun Python SDK. Contributions to the `mailgun-python` repository from the community are welcome and encouraged!

Mailgun loves developers. You can be part of this project!

This Python SDK is a great introduction to the open source world, check out the code!

Please create issues for any major changes so it can be discussed first. For small bug fixes feel free to submit the PR directly.

Make sure to run tests before creating the PR.

When submitting a pull request, please include the purpose and implementation details.

Feel free to ask anything, and contribute:

- Fork the project.
- Create a new branch.
- Implement your feature or bug fix.
- Add documentation to it.
- Commit, push, open a pull request and voila.

If you have suggestions on how to improve the guides, please submit an issue in our
[Official API Documentation](https://documentation.mailgun.com).
